.. _reference:

=========
Reference
=========

This is the technical reference for public APIs provided by VOC.

.. toctree::
   :maxdepth: 1

   Python signatures for Java-defined methods <signatures>
   The VOC type system <typesystem>
   Differences between VOC and CPython <differences> 
